#!/bin/sh

#  IBM Confidential
#  OCO Source Materials
#  Rational ClearCase
#  (C) Copyright IBM Corp. 1992, 2008  All Rights Reserved.
#
#  The source code for this program is not published or otherwise
#  divested of its trade secrets, irrespective of what has been
#  deposited with the U.S. Copyright Office.

#
# cleanlogs.sh - preserve and truncate logs nightly
#
# Revision history:
# henrik		09/17/91	initial version
# rtitle		07/17/02        added RWP log cleanup
#

#
# Find the log directory - exit if you can't.
#

ATRIA_DIR=${CLEARCASEHOME:-${ATRIAHOME:-/opt/rational/clearcase}}

if [ -d /var/adm/rational/clearcase/log ] 
then
	LOGDIR=/var/adm/rational/clearcase/log
else
	exit 1
fi	

#
# check for location of find
#

if [ -x /bin/find ]
then
	FIND=/bin/find
elif [ -x /usr/bin/find ]
then
	FIND=/usr/bin/find
else
	exit 1
fi

#
# Copy, or if we must, move the logfiles to logfile.old, and create a new,
# empty log file.
# Make them writable.
#

cd $LOGDIR

DO_MVFS_LOGS="TRUE"
if [ `uname -s` = "SunOS" ] ; then
  if [ -x /usr/sbin/zoneadm ] ; then
    ZONE=`/usr/sbin/zoneadm list -i | grep global`
    if [ "$ZONE" != "global" ] ; then
      # skip mvfs logs on SunOS NGZ
      DO_MVFS_LOGS="FALSE"
    fi
  fi
fi

for file in *_log
do
	#
	# Don't do the logfile for the lockmgr, as it doesn't have 
	# the same reopen logic as the other servers.
	#
	if [ $file != "lockmgr_log" -a $file != "mvfs_log" ]
	then
		rm $file.old >/dev/null 2>&1
		cp -p $file $file.old >/dev/null 2>&1
		if [ $? -ne 0 ] ; then
			rm $file.old >/dev/null 2>&1			
			mv $file $file.old
		fi
		cat < /dev/null >$file
		chmod 666 $file
	elif [ $file = "mvfs_log" -a -x ${ATRIA_DIR}/etc/mvfslog ]
	then
		if [ "$DO_MVFS_LOGS" = "TRUE" ] ; then
		  rm $file.old >/dev/null 2>&1
		  mv $file $file.old
		  cat < /dev/null >$file
		  chmod 666 $file
		  ${ATRIA_DIR}/etc/mvfslog -quiet -kernlog $file
	  	fi
	fi
done

#
# Manage the install logs.  Keep at least 5 and the most recent 8 days worth.
# Delete all the others.
#
if [ -x "$ATRIA_DIR/bin/Perl" ] 
then
    # Cryptic code notes:
    #     $#ARGV = index of last command line argument
    #     -M reports days since last modification.
    #     chomp(@ARGV) removes trailing white-space from EACH array member.
    $ATRIA_DIR/bin/Perl -e 'chomp(@ARGV);for($i=$#ARGV; $i > 4; $i--) { unlink($ARGV[$i]) if ( -M $ARGV[$i] > 8.0 );}' ` ls -t Atria_install* 2>/dev/null `
fi

# delete any MultiSite send* or recv* logs that are over 14 days old.
# these are found in the $LOGDIR/sync_logs subdirectory.
# UW and SNI 'rm' complain when no file name argument is provided.
# Walk around by adding 'dummy_file' as an argument.

if [ -d $LOGDIR/sync_logs ] 
then
    cd $LOGDIR/sync_logs
    $FIND . -name "recv-*_log" -mtime +14 -print | xargs /bin/rm -f dummy_file
    $FIND . -name "send-*_log" -mtime +14 -print | xargs /bin/rm -f dummy_file
fi

#
# Call the script that cleans up Rational Web Platform logs
# If RWP is not installed on this machine this is a no-op
#
# Under a Link-Install, the entire RWP directory tree will exist except the logs
# directory.  Check for the existance of the logs directory prior to invoking
# the scrubber.  If there are no logs, there is nothing to be done here.
#
RWPDIR=/opt/rational/common/rwp
if [ -d $RWPDIR ] 
then
    if [ -d $RWPDIR/logs ]
    then
        cd $RWPDIR/bin
        ./cleanuplogs
    fi
fi

exit 0
